@@ -41,7 +41,12 @@ class App:
             if self.player.playing:
                 self.player.pause()
         elif key == "q":
-            raise urwid.ExitMainLoop()
+            def _(x=None):
+                raise urwid.ExitMainLoop()
+            if self.player.playing:
+                task = self.loop.create_task(self.player.stop())
+                task.add_done_callback(_)
+            _()
 
     def _draw_table(self, items, title=None, prcnt=30, callback=None):
         if not callback:
@@ -162,10 +167,19 @@ class App:
             movies = await self.client.search(self.search_query, "Movie")
             shows = await self.client.search(self.search_query, "Series")
             episodes = await self.client.search(self.search_query, "Episode")
+            songs = await self.client.search(self.search_query, "Audio")
+            albums = await self.client.search(self.search_query, "MusicAlbum")
             self._add_widget(self.search_edit)
-            self._add_widget(self._draw_table(movies, "Movies", callback=self.play, prcnt=20))
-            self._add_widget(self._draw_table(shows, "Shows", callback=self.draw_seasons, prcnt=20))
-            self._add_widget(self._draw_table(episodes, "Episodes", callback=self.play, prcnt=20))
+            if movies:
+                self._add_widget(self._draw_table(movies, "Movies", callback=self.play, prcnt=20))
+            if shows:
+                self._add_widget(self._draw_table(shows, "Shows", callback=self.draw_seasons, prcnt=20))
+            if episodes:
+                self._add_widget(self._draw_table(episodes, "Episodes", callback=self.play, prcnt=20))
+            if songs:
+                self._add_widget(self._draw_table(songs, "Songs", callback=self.play_bg, prcnt=20))
+            if albums:
+                self._add_widget(self._draw_table(albums, "Albums", callback=self.draw_album, prcnt=20))
         else:
             urwid.connect_signal(self.search_edit, "change", self.draw_search)
             recommended = await self.client.get_recommended()
